package Qt::Core::QStateMachine::WrappedEvent;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStateMachine::WrappedEvent
# file     : QtCore/qstatemachine.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QEvent/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Core::QStateMachine::WrappedEvent

=head1 PUBLIC METHODS

=over

=item   QStateMachine::WrappedEvent(QObject * object, QEvent * event)

=item   ~WrappedEvent()

=item  QEvent * event()

=item  QObject * object()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
